struct Surface {
kind: RenderTargetKind,
allocator: GuillotineAllocator,
is_shared: bool,
lifetime_group: PassId,
pending_frees: usize,
}Expand description
An internal representation of a dynamic surface that tasks can be allocated into. Maintains some extra metadata about each surface during the graph build.
Fields
kind: RenderTargetKindWhether this is a color or alpha render target
allocator: GuillotineAllocatorAllocator for this surface texture
We can only allocate into this for reuse if it’s a shared surface
lifetime_group: PassIdThe lifetime group of this surface: only tasks with a matching lifetime_group can share it, to avoid holding the surface longer than necessary.
pending_frees: usizeReference count: number of tasks whose individual free_after will trigger a decrement. Surface is returned to the pool when this reaches 0.
Implementations
Sourceimpl Surface
impl Surface
Sourcefn alloc_rect(
&mut self,
size: DeviceIntSize,
kind: RenderTargetKind,
is_shared: bool,
lifetime_group: PassId,
) -> Option<DeviceIntPoint>
fn alloc_rect( &mut self, size: DeviceIntSize, kind: RenderTargetKind, is_shared: bool, lifetime_group: PassId, ) -> Option<DeviceIntPoint>
Allocate a rect within a shared surfce. Returns None if the format doesn’t match, or allocation fails.